diceware

package module
v0.0.0-...-8c7fbc7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2023 License: GPL-3.0 Imports: 4 Imported by: 4

README

Diceware

What is Diceware?

From the official site:

Diceware™ is a method for picking passphrases that uses dice to select words at random from a special list called the Diceware Word List.

This project is now using the new word list from the EFF, which contain many improvements over the original Diceware word list.

Examples

$ diceware
regulatorvotinggauntlettreadingwidenuntried
$ diceware -delimiter " "
cozily troubling flask trapezoid waving throwback
$ diceware -delimiter "-"
ablaze-marmalade-axis-appetite-skyward-enigmatic
$ diceware -words 10 -delimiter "-"
that-giddily-repressed-setback-musty-predict-recede-bagging-pointer-uncurled

Installation

go install github.com/btoll/diceware@latest

CLI Usage

Option | Description
------------ | -------------
-words | The length of the passphrase (defaults to six words).
-delimiter | The character that joins the words.
-h, --help | Display help.

Scripting Usage

Command | Description
------------ | -------------
generate(n) | Generates a passphrase of word length `n` using the Diceware method.

Ports

License

GPLv3

Author

Benjamin Toll

Documentation

Index

Constants

This section is empty.

Variables

var Words = map[string]string{}/* 7776 elements not displayed */

Functions

func Generate

func Generate(n int, delimiter string) (string, error)

Generate generates a cryptographically-secure Diceware passphrase.

Types

This section is empty.

Jump to